/**
 * Class to test DiceTally (modified to illustrate exceptions)
 */

import java.io.*;

public class DiceDriver
{	
	/* since IOException is checked, THIS METHOD must either 
	 *  1) handle the exception explicitly with a try/catch *OR*
	 *  2) advertise that it might throw an IOException with a throws clause
	 */
	public static void main(String[] args) throws IOException // a throws clause (item 2)
	{
		BufferedReader input=null;  // this null is needed because the construction in the
									// next statement might not be executed
		
		try {
			 input = new BufferedReader(new InputStreamReader(System.in));
		}
		catch (Exception e) {
			System.out.println("Error in reader construction");  // a helpful message
			System.out.println(e);  // what is printed? - the name of the exception
			e.printStackTrace();  // prints the exception's name AND tells you how you got here
			System.exit(1);  // you don't HAVE to exit if the particular exceptional condition
							 // can be repaired; the program would then continue below
		}
		
		System.out.print("Enter number of rolls: ");
			
		String str = input.readLine(); 
		// since readLine() can also throw IOException, if the above IOException
		// is caught explicitly, this statement will also need a try/catch (or this statement
		// could be put in the above try block)
		// OR the method will need a throws IOException clause appended to its header
		
		int numRolls = Integer.parseInt(str);
		
		DiceTally t = new DiceTally(numRolls);
		t.throwDice();
		
		System.out.println(t);	
	}
}
