/**
 * Class ShowManager which manages a fireworks show
 * originally written by Scott McElfresh, February 2003
 * modified by da' Moose, February 2003
 * modified by mjs, June 2003
 */

import java.awt.*;
import java.util.Random;
import javax.swing.JOptionPane;

public class ShowManager extends Frame
{
	private WindowCloser myCloser;

	/**
	 * constructor to specify width and height - automatically make the window visible
	 * and allow it to be closed.
	 */
	public ShowManager(int width, int height)
	{
	   setSize(width,height);
	   setTitle("Fireworks program");
	   myCloser = new WindowCloser();
	   addWindowListener(myCloser);
	   setVisible(true);
	}  
  
	/**
	 * this is called automatically by the system at various times.  We are telling
	 * it to do nothing special. It is empty for a reason.  Leave it that way.
	 */
	public void paint(Graphics g)
	{ }

 	/**
 	 * Does the actual drawing in this frame
 	 */
	public void doDrawing()
	{
		CustomDelay d = new CustomDelay();
	    d.doDelay(1000);       // give the system time to get everything set up
	    Graphics g = getGraphics();   // get the graphics context for the frame
		Random r = new Random();
	   
		// build the fireworks supplier
	    Supplier s = new Supplier();

        // get user input for number of fireworks
	    String input;
		input = JOptionPane.showInputDialog("How many fireworks would you like? ");
		int numberOfFireworks = Integer.parseInt(input);

	    d.doDelay(1000);
	    // draw the night sky
	    for (int i = 0; i < 255; i += 5)
	    {
	    	Color customBlack = new Color(0,0,0,i);
		    g.setColor(customBlack);
		    g.fillRect(0,0,getWidth(),getHeight());  
		    d.doDelay(30); 
	    }
		    
	    // launch the user requested number of fireworks
	    for (int i = 0; i < numberOfFireworks; i++)
	    {
	       // generate x coordinate of the launch point
	       int x = r.nextInt(getWidth() - 100) + 50;
	       // generate the y coordinate of the height of the explosion
	       int explosionHeight = getHeight() - 150 - (r.nextInt(getHeight() - 300));
	       // wrap them up in a Point
	       Point p = new Point(x,explosionHeight);
	       // order the firework from the supplier
	       Firework f = s.createFirework();
	       // fire it
	       f.fire(p,this);
	       d.doDelay(1000);
	    }
	   
	   	// launch the big finale...
	    Finale fin = new Finale();
	    fin.bigEnding(this);
	    // to explicitly terminate all execution threads
	    System.exit(0);
	}
}