import java.util.Random;
import java.util.ArrayList;

public class TallyVector
{
    private int[] tally;
    private static Random rg;
    private int totalCount;;

    /** Instantiates an array to hold the frequencies for values from 0 to
     *  topValue.
     *  Sets all frequencies to 0 and totalCount to 0
     *  Instantiates the random generator, rg
     *  @param topValue, the maximum value to be stored in the array
     */
    public TallyVector(int topValue)
    {
	totalCount = 0;
	rg = new Random();
	tally = new int[topValue+1];
	for (int i = 0; i < tally.length; i++)
	    tally[i] = 0;
    }

    /** Returns the total of all values in the TallyVector object
     *  @return the total count of all values stored
     */
    public int size()
    {
	return totalCount;
    }

    /** randomly populates the TallyVector with n values between 0 and topValue
     *  @param n the number of values to populate the TallyVector
     */
    public void populate(int n)
    {
	for (int i = 0; i < n; i++)
	{
	    int val = rg.nextInt(tally.length);
	    tally[val]++;
	    totalCount++;
	}
	/*
	tally[2] = 10;
	tally[3] = 5;
	tally[4] = 10;
	tally[6] = 7;
	tally[7] = 1;
	tally[9] = 6;
	tally[11] = 10;
	tally[12] = 3;
	tally[15] = 1;
	totalCount = 53;
	*/
    }

    public String toString()
    {
	String result = "Value";
	for (int i = 0; i < tally.length; i++)
	    result += "\t" + i;
	result += "\nFreq";
	for (int i = 0; i < tally.length; i++)
	    result += "\t" + tally[i];
	return result;
    }

    /** returns the maximally occurring frequency
     *  precondition: tally.length > 0
     *  @return the highest frequency count that occurs in the TallyVector
     */
    private int findMax()
    {
	int currMax = tally[0];
	for (int i = 0; i < tally.length; i++)
	    if (tally[i] > currMax)
		currMax = tally[i];
	return currMax;
    }

    /** returns an ArrayList of the all the modal values
     *  @return an ArrayList of all the values in TallyVector equal to mode
     */
    public ArrayList calculateModes()
    {
	ArrayList a = new ArrayList();
	int max = findMax();
	for (int i = 0; i < tally.length; i++)
	    if (tally[i] == max)
		a.add(new Integer(i));
	return a;
    }

    /** returns the kth value in the TallyVector
     *  precondition: tally.length > 0
                      0 < k <= totalCOunt
     * @return kth value stored
     */
    public int kthValue(int k)
    {
	int index = 0;
	int count = tally[0];
	while (count < k)
	{
	    index++;
	    count += tally[index];
	}
	return index;
    }

    public static void main(String[] ar)
    {
	TallyVector t = new TallyVector(3);
	t.populate(15);
	System.out.println(t);
	System.out.println("Mode(s) = " + t.calculateModes());
	System.out.println("6th value is " + t.kthValue(6));
    }
}
